fgpdset: Fit collection of GPD models to compounding exceedances as...

Description Usage Arguments Value

Description

Fit collection of GPD models to compounding exceedances as defined in get_exceedances

Usage

1
2
3
fgpdset(excd.list, Xb, type = c("upper", "lower"), return.qs = FALSE,
  pred.taus = NULL, use.winter.shape = FALSE, all.winter.ind = NULL,
  Xb.pred.time = NULL)

Arguments

excd.list

list of exceedances created by get_exceedances

Xb

basis design matrix for tails (log(scale) of GPD). Each basis function is in a separate column.

type

one of "upper" or "lower" if fitting upper or lower tails

return.qs

(logical) should quantile estimates be returned

pred.taus

vector of quantiles to predict

use.winter.shape

(logical) should a separate shape parameter be estimated for the winter months?

all.winter.ind

indicator for which dates correspond to winter months

Xb.pred.time

Basis matrix for prediction dates.

Value

List of fitted parameter matrix (one column for each GPD order: log(scale), shape) and estimated quantiles (qs, of dimension time, taus, model).


gbstat/tailqr documentation built on May 8, 2019, 5:42 p.m.