Description Usage Arguments Value
Estimate a weighted quantile given several estimates of the same quantile from different QR and GPD models
1 2 | calc_weighted_quantile(qs, taus, thresh.taus, end.tau, type = c("upper",
"lower"))
|
qs |
quantile estimates from different QR and GPD models |
taus |
quantiles to estimate |
thresh.taus |
vector of quantiles, above which the GPDs are defined |
end.tau |
Last quantile, above which the outer most GPD gets all the weight and the remaining have weight zero |
type |
One of "upper" or "lower" depending on if upper or lower quantiles are being estimated |
weighted estimate of a quantile
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.