Description Usage Arguments Value
Fit collection of GPD models to compounding exceedances as defined in
get_exceedances
1 2 3 |
excd.list |
list of exceedances created by |
Xb |
basis design matrix for tails (log(scale) of GPD). Each basis function is in a separate column. |
type |
one of "upper" or "lower" if fitting upper or lower tails |
return.qs |
(logical) should quantile estimates be returned |
pred.taus |
vector of quantiles to predict |
use.winter.shape |
(logical) should a separate shape parameter be estimated for the winter months? |
all.winter.ind |
indicator for which dates correspond to winter months |
Xb.pred.time |
Basis matrix for prediction dates. |
List of fitted parameter matrix (one column for each GPD order: log(scale), shape) and estimated quantiles (qs, of dimension time, taus, model).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.